==> lordsawar-0.0.2.tar.gz: lordsawar-0.0.2/src/editor/ruin-dialog.cpp <==
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*

#include <config.h>

#include <libglademm/xml.h>
#include <sigc++/functors/mem_fun.h>
#include <gtkmm/alignment.h>

#include "ruin-dialog.h"

#include "glade-helpers.h"
#include "../ucompose.hpp"
#include "../playerlist.h"
#include "../defs.h"
#include "../ruin.h"
#include "../stack.h"
#include "../army.h"

#include "stack-dialog.h"

RuinDialog::RuinDialog(Ruin *r)
{
    ruin = r;
    
    // copy occupant to be able to undo if the dialog is cancelled
    Stack *occupant = ruin->getOccupant();
    if (occupant)
	keeper = new Stack(*occupant);
    else
	keeper = new Stack(0, ruin->getPos());
    
    Glib::RefPtr<Gnome::Glade::Xml> xml
	= Gnome::Glade::Xml::create(get_glade_path()
				    + "/ruin-dialog.glade");

    Gtk::Dialog *d = 0;
    xml->get_widget("dialog", d);
    dialog.reset(d);

    xml->get_widget("name_entry", name_entry);
    name_entry->set_text(ruin->getName());

    xml->get_widget("keeper_button", keeper_button);
    keeper_button->signal_clicked().connect(
	sigc::mem_fun(this, &RuinDialog::on_keeper_clicked));

    set_keeper_name();
    xml->get_widget("sage_checkbutton", sage_button);
    sage_button->set_active(ruin->hasSage());
   
    xml->get_widget("hidden_checkbutton", hidden_button);
    hidden_button->set_active(ruin->isHidden());
    hidden_button->signal_toggled().connect(
	    sigc::mem_fun(this, &RuinDialog::on_hidden_toggled));
    // setup the player combo
    player_combobox = manage(new Gtk::ComboBoxText);

    int c = 0, player_no = 0;
    for (Playerlist::iterator i = Playerlist::getInstance()->begin(),
	     end = Playerlist::getInstance()->end(); i != end; ++i, ++c)
    {
	Player *player = *i;
	player_combobox->append_text(player->getName());
	if (player == ruin->getOwner())
	    player_no = c;
    }

    player_combobox->set_active(player_no);

    Gtk::Alignment *alignment;
    xml->get_widget("player_alignment", alignment);
    alignment->add(*player_combobox);
    on_hidden_toggled();
}

void RuinDialog::set_parent_window(Gtk::Window &parent)
{
    dialog->set_transient_for(parent);
    //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
}

void RuinDialog::run()
{
    dialog->show_all();
    int response = dialog->run();

    if (response == 0)		// accepted
    {
        ruin->setName(name_entry->get_text());

	// get rid of old occupant and insert new
	Stack *occupant = ruin->getOccupant();
	if (occupant)
	    delete occupant;

	if (keeper->empty())
	{
	    delete keeper;
	    keeper = 0;
	}

	ruin->setOccupant(keeper);
        ruin->setSage(sage_button->get_active());
        ruin->setHidden(hidden_button->get_active());
        if (hidden_button->get_active())
          {
	    // set owner
	    int c = 0, row = player_combobox->get_active_row_number();
	    Player *player = Playerlist::getInstance()->getNeutral();
	    for (Playerlist::iterator i = Playerlist::getInstance()->begin(),
		     end = Playerlist::getInstance()->end(); i != end; ++i, ++c)
	        if (c == row)
	        {
		    player = *i;
		    break;
	        }
	    ruin->setOwner(player);
          }
        else
          ruin->setOwner(NULL);
	keeper = 0;
    }
    else
    {
	delete keeper;
	keeper = 0;
    }
}

void RuinDialog::set_keeper_name()
{
    Glib::ustring name;
    if (keeper && !keeper->empty())
	name = keeper->getStrongestArmy()->getName();
    else
	name = _("No keeper");
    
    keeper_button->set_label(name);
}

void RuinDialog::on_hidden_toggled()
{
  if (hidden_button->get_active())
    player_combobox->set_sensitive (true);
  else
    player_combobox->set_sensitive (false);
}

void RuinDialog::on_keeper_clicked()
{
    // FIXME: run stack dialog with keeper
    StackDialog d(keeper, 0);
    d.set_parent_window(*dialog.get());
    d.run();

    set_keeper_name();
}

==> lordsawar_0.0.8.orig.tar.gz: lordsawar-0.0.8/src/editor/ruin-dialog.cpp <==
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.*

#include <config.h>

#include <libglademm/xml.h>
#include <sigc++/functors/mem_fun.h>
#include <gtkmm/alignment.h>

#include "ruin-dialog.h"

#include "glade-helpers.h"
#include "../ucompose.hpp"
#include "../playerlist.h"
#include "../defs.h"
#include "../ruin.h"
#include "../stack.h"
#include "../army.h"

#include "stack-dialog.h"

RuinDialog::RuinDialog(Ruin *r)
{
    ruin = r;
    
    // copy occupant to be able to undo if the dialog is cancelled
    Stack *occupant = ruin->getOccupant();
    if (occupant)
	keeper = new Stack(*occupant);
    else
	keeper = new Stack(0, ruin->getPos());
    
    Glib::RefPtr<Gnome::Glade::Xml> xml
	= Gnome::Glade::Xml::create(get_glade_path()
				    + "/ruin-dialog.glade");

    Gtk::Dialog *d = 0;
    xml->get_widget("dialog", d);
    dialog.reset(d);

    xml->get_widget("name_entry", name_entry);
    name_entry->set_text(ruin->getName());

    xml->get_widget("type_entry", type_entry);
    type_entry->set_value(ruin->getType());

    xml->get_widget("keeper_button", keeper_button);
    keeper_button->signal_clicked().connect(
	sigc::mem_fun(this, &RuinDialog::on_keeper_clicked));

    set_keeper_name();
    xml->get_widget("sage_checkbutton", sage_button);
    sage_button->set_active(ruin->hasSage());
   
    xml->get_widget("hidden_checkbutton", hidden_button);
    hidden_button->set_active(ruin->isHidden());
    hidden_button->signal_toggled().connect(
	    sigc::mem_fun(this, &RuinDialog::on_hidden_toggled));
    // setup the player combo
    player_combobox = manage(new Gtk::ComboBoxText);

    int c = 0, player_no = 0;
    for (Playerlist::iterator i = Playerlist::getInstance()->begin(),
	     end = Playerlist::getInstance()->end(); i != end; ++i, ++c)
    {
	Player *player = *i;
	player_combobox->append_text(player->getName());
	if (player == ruin->getOwner())
	    player_no = c;
    }

    player_combobox->set_active(player_no);

    Gtk::Alignment *alignment;
    xml->get_widget("player_alignment", alignment);
    alignment->add(*player_combobox);
    on_hidden_toggled();
}

void RuinDialog::set_parent_window(Gtk::Window &parent)
{
    dialog->set_transient_for(parent);
    //dialog->set_position(Gtk::WIN_POS_CENTER_ON_PARENT);
}

void RuinDialog::run()
{
    dialog->show_all();
    int response = dialog->run();

    if (response == 0)		// accepted
    {
        ruin->setName(name_entry->get_text());
	ruin->setType(type_entry->get_value_as_int());

	// get rid of old occupant and insert new
	Stack *occupant = ruin->getOccupant();
	if (occupant)
	    delete occupant;

	if (keeper->empty())
	{
	    delete keeper;
	    keeper = 0;
	}

	ruin->setOccupant(keeper);
        ruin->setSage(sage_button->get_active());
        ruin->setHidden(hidden_button->get_active());
        if (hidden_button->get_active())
          {
	    // set owner
	    int c = 0, row = player_combobox->get_active_row_number();
	    Player *player = Playerlist::getInstance()->getNeutral();
	    for (Playerlist::iterator i = Playerlist::getInstance()->begin(),
		     end = Playerlist::getInstance()->end(); i != end; ++i, ++c)
	        if (c == row)
	        {
		    player = *i;
		    break;
	        }
	    ruin->setOwner(player);
          }
        else
          ruin->setOwner(NULL);
	keeper = 0;
    }
    else
    {
	delete keeper;
	keeper = 0;
    }
}

void RuinDialog::set_keeper_name()
{
    Glib::ustring name;
    if (keeper && !keeper->empty())
	name = keeper->getStrongestArmy()->getName();
    else
	name = _("No keeper");
    
    keeper_button->set_label(name);
}

void RuinDialog::on_hidden_toggled()
{
  if (hidden_button->get_active())
    player_combobox->set_sensitive (true);
  else
    player_combobox->set_sensitive (false);
}

void RuinDialog::on_keeper_clicked()
{
    // FIXME: run stack dialog with keeper
    StackDialog d(keeper, 0);
    d.set_parent_window(*dialog.get());
    d.run();

    set_keeper_name();
}
